Learn R Programming

specmine (version 1.0)

aov_all_vars: Analysis of variance

Description

Perform analysis of variance of all variables in the dataset.

Usage

aov_all_vars(dataset, column.class, doTukey = T, write.file = F, file.out = "anova-res.csv")

Arguments

dataset
list representing the dataset from a metabolomics experiment.
column.class
string or index indicating what metadata to use.
doTukey
boolean value for do or do not TukeyHSD.
write.file
boolean value indicating if a file with the results is written or not.
file.out
name of the file if write.file is TRUE.

Value

Data frame with the results of ANOVA, with p-value, logarithm of p-value, false discovery rate (fdr) and tukey is doTukey is TRUE. The result is ordered by p-value.

Examples

Run this code
  ## Example of ANOVA with TukeyHSD
  data(cassavaPPD)
  cassavaPPD = flat_pattern_filter(cassavaPPD, "iqr", by.percent = TRUE,
	red.value = 75) 
  result = aov_all_vars(cassavaPPD, "varieties", doTukey = FALSE)

Run the code above in your browser using DataLab