powered by
Converts a vector of HMDB codes into a vector of the corresponding KEGG codes.
convert_hmdb_to_kegg(hmdb_codes)
Vector with the HMDB codes (each hmdb code must have 7 digits, e.g., HMDB0000001)
Named vector with kegg codes and respective names. Vector names are the compound names and the vector elements the kegg codes.
# NOT RUN { keggs=convert_hmdb_to_kegg(c("HMDB0000001", "HMDB0000008", "HMDB0000246")) keggs # }
Run the code above in your browser using DataLab