convert_keggpathway_2_reactiongraph: Convert KEGGPathway object to graph object

View source: R/PATHWAY_ANALYSIS.R

convert_keggpathway_2_reactiongraphR Documentation

Convert KEGGPathway object to graph object

Description

Convert KEGGPathway object to graph object

Usage

convert_keggpathway_2_reactiongraph(pathObj)

Arguments

pathObj

TODO.

Value

A graph object representing the reactions in the input KEGGPathway object. The returned object is suitable for graph-based inspection or for use in downstream visualization functions.

Examples

## Not run: 
path <- get_MetabolitePath("hsa00010")
graph <- convert_keggpathway_2_reactiongraph(path)
class(graph)

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.