View source: R/filter_dataset.R
| count_missing_values | R Documentation |
Returns the total number of missing values in the dataset.
count_missing_values(dataset)
dataset |
Dataset to inspect. |
A single numeric value giving the total count of 'NA' entries present in 'dataset$data'.
data <- matrix(
c(1, NA, 3, 4),
nrow = 2,
dimnames = list(c("x1", "x2"), c("s1", "s2"))
)
metadata <- data.frame(class = c("A", "B"), row.names = c("s1", "s2"))
dataset <- list(data = data, metadata = metadata)
count_missing_values(dataset)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.