create_pathway_with_reactions: Creates the pathway, with reactions included in the nodes

View source: R/PATHWAY_ANALYSIS.R

create_pathway_with_reactionsR Documentation

Creates the pathway, with reactions included in the nodes

Description

Creates the pathway, with reactions included in the nodes

Usage

create_pathway_with_reactions(
  path,
  path.name,
  identified_cpds,
  nodeNames = "kegg",
  nodeTooltip = FALSE,
  map.zoom = FALSE,
  map.layout = "preset",
  map.width = NULL,
  map.height = NULL
)

Arguments

path

TODO.

path.name

TODO.

identified_cpds

TODO.

nodeNames

TODO.

nodeTooltip

TODO.

map.zoom

TODO.

map.layout

TODO.

map.width

TODO.

map.height

TODO.

Value

A cyjShiny widget representing the pathway with reactions included in the nodes. The widget contains the pathway graph ready for interactive visualization, with identified compounds highlighted when they are present in the pathway.

Examples

## Not run: 
path <- get_MetabolitePath("hsa00010")
create_pathway_with_reactions(
  path = path,
  path.name = "hsa00010",
  identified_cpds = c("cpd:C00031", "cpd:C00022")
)

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.