Learn R Programming

specmine (version 1.0)

fold_change_var: Fold change applied on two variables

Description

Fold change applied on two variables. Instead of having the difference of the variables on two groups, we have the difference of the groups on two variables.

Usage

fold_change_var(dataset, metadata.var, variables, threshold.min.fc = NULL, write.file = F, file.out = "fold_change_reverse.csv")

Arguments

dataset
list representing the dataset from a metabolomics experiment.
metadata.var
metadata to use to calculate the fold change.
variables
vector with two positions containing the name of the variables.
threshold.min.fc
minimum threshold of the fold change value.
write.file
boolean value to write or not a file with the results.
file.out
name of the file.

Value

Table of results with fold change and log2 of fold change.

Examples

Run this code
  ## Example of fold change reverse
  data(cachexia)
  fold.change.results = fold_change_var(cachexia, "Muscle.loss", 
			c("Creatine", "Serine"))

Run the code above in your browser using DataLab