get_MetabolitePath: Returns an object of KEGGPathway of the pathway especified in...

View source: R/PATHWAY_ANALYSIS.R

get_MetabolitePathR Documentation

Returns an object of KEGGPathway of the pathway especified in pathcode

Description

Returns an object of KEGGPathway of the pathway especified in pathcode

Usage

get_MetabolitePath(pathcode)

Arguments

pathcode

TODO.

Value

A KEGGPathway object corresponding to the pathway specified by pathcode. This object contains the parsed KEGG pathway structure and can be used as input to downstream graph conversion and visualization functions.

Examples

## Not run: 
path <- get_MetabolitePath("hsa00010")
class(path)

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.