get_OrganismsCodes: Get code, t number, full name and phylogeny of all organisms...

View source: R/PATHWAY_ANALYSIS.R

get_OrganismsCodesR Documentation

Get code, t number, full name and phylogeny of all organisms in KEGG:

Description

Get code, t number, full name and phylogeny of all organisms in KEGG:

Usage

get_OrganismsCodes()

Value

A data.frame with the KEGG T number, organism code, species names, and phylogeny for all organisms available in KEGG. Each row represents one organism and the columns are Tnumber, organismCode, speciesNames, and phylogeny.

Examples

## Not run: 
head(get_OrganismsCodes())

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.