get_cpd_names: Get compound names from KEGG codes

View source: R/PATHWAY_ANALYSIS.R

get_cpd_namesR Documentation

Get compound names from KEGG codes

Description

Returns compound names associated with KEGG compound identifiers.

Usage

get_cpd_names(kegg_codes)

Arguments

kegg_codes

Character vector of KEGG compound identifiers.

Value

A named character vector in which the values are KEGG compound identifiers and the names are the corresponding compound names. Each element of the returned vector represents one KEGG compound code matched to its primary compound name.

Examples

## Not run: 
get_cpd_names(c("C00031", "C00022"))

## End(Not run)

specmine documentation built on Aug. 5, 2026, 5:06 p.m.