get_metabolights_study_files_assay: Download files for one MetaboLights assay

View source: R/get_metabolights_study.R

get_metabolights_study_files_assayR Documentation

Download files for one MetaboLights assay

Description

Downloads the data files associated with one assay of a MetaboLights study.

Usage

get_metabolights_study_files_assay(studyID, assay, directory, verbose = TRUE)

Arguments

studyID

Character string with the MetaboLights study identifier.

assay

Numeric or character index selecting the assay in the study.

directory

Output directory where assay files will be downloaded.

verbose

Logical indicating whether progress messages should be shown.

Value

Invisibly returns a character vector with downloaded file paths.

Examples

## Not run: 
tmpdir <- tempdir()
get_metabolights_study_files_assay("MTBLS1", assay = 1, directory = tmpdir, verbose = FALSE)

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.