Learn R Programming

specmine (version 2.0.3)

get_metabolights_study_list: List of metabolights studies available to download.

Description

Returns a vector with the IDs of all metabolights studies available to download. Not all data in metabolights is in a format readable by specmine.

Usage

get_metabolights_study_list()

Arguments

Value

Character vector with the IDs of the metabolights studies available to download.

Warning

You must not call this function unless you have Python (>=3.5.2) installed in your machine and the module isatools.

Examples

Run this code
# NOT RUN {
##get_metabolights_study_list()
# }

Run the code above in your browser using DataLab