get_metabolights_study_metadata_assay: Get metadata for one MetaboLights assay

View source: R/get_metabolights_study.R

get_metabolights_study_metadata_assayR Documentation

Get metadata for one MetaboLights assay

Description

Returns the metadata associated with the samples in one assay of a MetaboLights study and can optionally save it as a CSV file.

Usage

get_metabolights_study_metadata_assay(studyID, assay, directory = NULL)

Arguments

studyID

Character string with the MetaboLights study identifier.

assay

Numeric or character index selecting the assay in the study.

directory

Optional output directory where the metadata CSV will be written.

Value

Invisibly returns a data.frame with sample metadata for the selected assay.

Examples

## Not run: 
md <- get_metabolights_study_metadata_assay("MTBLS1", assay = 1)
head(md)

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.