get_metabolights_study_samples_files: Get sample-file mapping for one MetaboLights assay

View source: R/get_metabolights_study.R

get_metabolights_study_samples_filesR Documentation

Get sample-file mapping for one MetaboLights assay

Description

Returns the sample-to-file mapping for one assay in a MetaboLights study and can optionally save it as a CSV file.

Usage

get_metabolights_study_samples_files(studyID, assay, directory = NULL)

Arguments

studyID

Character string with the MetaboLights study identifier.

assay

Numeric or character index selecting the assay in the study.

directory

Optional output directory where samples_files.csv will be written.

Value

Invisibly returns a two-column object with samples and corresponding files.

Examples

## Not run: 
get_metabolights_study_samples_files("MTBLS1", assay = 1)

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.