get_peak_values: Auto-exported function: get_peak_values

get_peak_valuesR Documentation

Auto-exported function: get_peak_values

Description

Auto-exported function: get_peak_values

Usage

get_peak_values(samples.df, peak.val)

Arguments

samples.df

A data frame of peak intensities with peaks in rows and samples in columns.

peak.val

Peak value identifying the row to extract.

Value

A numeric vector with the intensity values for the peak specified by peak.val across all samples in samples.df.

Examples

samples.df <- data.frame(
  s1 = c(10, 20),
  s2 = c(15, NA),
  row.names = c("1", "2")
)
get_peak_values(samples.df, "1")


specmine documentation built on Aug. 5, 2026, 5:06 p.m.