Learn R Programming

specmine (version 1.0)

is_spectra: Check type of data

Description

Check if the dataset is from spectral data where x.values are numeric.

Usage

is_spectra(dataset)

Arguments

dataset
list representing the dataset from a metabolomics experiment.

Value

Returns a boolean indicating if the dataset is from spectral data or not.

Examples

Run this code
  ## Example of checking if the dataset is from spectral data
  data(cassavaPPD)
  is_spectra(cassavaPPD)

Run the code above in your browser using DataLab