Learn R Programming

specmine (version 2.0.3)

jaccard_index: Jaccard Index

Description

Calculates the jaccard index, i.e., the similarity between cluster and reference metabolite, in an NMR metabolite identification.

Usage

jaccard_index(peaksCluster, peaksReference, PPMTOL)

Arguments

peaksCluster

Dataframe with the peaks of a cluster. First column corresponds to the peaks in ppm and the second one to the intensity of those peaks.

peaksReference

Dataframe with the peaks of a reference spectrum. First column corresponds to the peaks in ppm and the second one to the intensity of those peaks.

PPMTOL

ppm tolerance to consider the pairing of two peaks from the cluster and reference a match.