Learn R Programming

specmine (version 1.0)

kruskalTest_dataset: Kruskal-Wallis tests on dataset

Description

Run Kruskal-Wallis Tests for each row of the data from the dataset.

Usage

kruskalTest_dataset(dataset, metadata.var, threshold = NULL, write.file = F, file.out = "kruskal.csv")

Arguments

dataset
list representing the dataset from a metabolomics experiment.
metadata.var
metadata variable to use in the t-tests.
threshold
threshold value of the p-value.
write.file
boolean value to write or not a file with the results.
file.out
name of the file.

Value

Table with the results of the Kruskal-Wallis tests, with p-value, -log10(p-value) and false discovery rate (fdr).

Examples

Run this code
  ## Example of ks-Tests on dataset
  data(cachexia)
  kruskaltests.result = kruskalTest_dataset(cachexia, "Muscle.loss", 
		  write.file = FALSE)

Run the code above in your browser using DataLab