Learn R Programming

specmine (version 1.0)

multifactor_aov_all_vars: Multifactor ANOVA

Description

Perform multi-factor ANOVA on all variables with the selected metadata variables.

Usage

multifactor_aov_all_vars(dataset, metadata.vars, combination)

Arguments

dataset
list representing the dataset from a metabolomics experiment.
metadata.vars
metadata variables to use in ANOVA.
combination
a formula specifying the model.

Value

List where each element is the multifactor anova result of a variable on the dataset.

Examples

Run this code
  ## Example of multifactor ANOVA on all variables 
  data(propolis)
  propolis = missingvalues_imputation(propolis, "value", value = 0.00005)
  m.aov.results = multifactor_aov_all_vars(propolis, 
		  c("seasons","agroregions"), "seasons*agroregions")

Run the code above in your browser using DataLab