Learn R Programming

specmine (version 2.0.3)

nmr_1d_spectra_options: Conditions of acquirement of the different refernece peak lists.

Description

Dataframe with what conditions each reference peak list was obtained: frequency, nuleus, pH, temperature and solvent. This dataset is used to filter the reference metabolites in the identification of 1D-NMR peak lists samples.

Usage

data("nmr_1d_spectra_options")

Arguments