pathway_analysis: Creates the pathway wanted. If any of the given compounds is...

View source: R/PATHWAY_ANALYSIS.R

pathway_analysisR Documentation

Creates the pathway wanted. If any of the given compounds is present in the pathway, it is coloured differently.

Description

Creates the pathway wanted. If any of the given compounds is present in the pathway, it is coloured differently.

Usage

pathway_analysis(
  compounds,
  pathway,
  nodeNames = "kegg",
  nodeTooltip = FALSE,
  map.zoom = FALSE,
  map.layout = "preset",
  map.width = NULL,
  map.height = NULL,
  verbose = TRUE
)

Arguments

compounds

TODO.

pathway

TODO.

nodeNames

TODO.

nodeTooltip

TODO.

map.zoom

TODO.

map.layout

TODO.

map.width

TODO.

map.height

TODO.

verbose

Logical indicating whether progress messages should be shown.

Value

A cyjShiny widget representing the selected pathway with the input compounds highlighted when present. The returned widget can be printed or embedded in an interactive R session to inspect the pathway graph.

Examples

## Not run: 
pathway_analysis(
  compounds = c(glucose = "cpd:C00031", pyruvate = "cpd:C00022"),
  pathway = "hsa00010",
  verbose = FALSE
)

## End(Not run)


specmine documentation built on Aug. 5, 2026, 5:06 p.m.