| read_multiple_csvs | R Documentation |
Reads multiple CSV files, one per sample, and returns them as a named list.
read_multiple_csvs(filenames, ext = ".csv", verbose = TRUE, ...)
filenames |
Character vector with file names or file paths. |
ext |
File extension appended to each file name. |
verbose |
Logical; whether progress messages should be shown. |
... |
Additional arguments passed to |
A named list of data frames, one per input file.
f1 <- tempfile(fileext = ".csv")
f2 <- tempfile(fileext = ".csv")
utils::write.csv(data.frame(ppm = c(1, 2), int = c(10, 20)), f1, row.names = FALSE)
utils::write.csv(data.frame(ppm = c(1, 3), int = c(15, 30)), f2, row.names = FALSE)
read_multiple_csvs(c(f1, f2), ext = "", verbose = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.