View source: R/filter_dataset.R
| subset_x_values_by_interval | R Documentation |
Selects x values within a numeric interval.
subset_x_values_by_interval(dataset, min.value, max.value)
dataset |
Dataset to subset. |
min.value |
Minimum x value. |
max.value |
Maximum x value. |
A dataset object with the same structure as the input, where 'dataset$data' contains only variables whose x values fall between 'min.value' and 'max.value', inclusive.
data <- matrix(
1:12,
nrow = 4,
dimnames = list(c("10", "20", "30", "40"), c("s1", "s2", "s3"))
)
metadata <- data.frame(group = c("A", "B", "A"), row.names = c("s1", "s2", "s3"))
dataset <- list(data = data, metadata = metadata)
subset_x_values_by_interval(dataset, 15, 35)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.