Learn R Programming

specmine (version 1.0)

xvalue_interval_to_indexes: Get indexes of an interval of x-values

Description

Returns indexes corresponding to an interval of x-values (only to numerical values - spectra)

Usage

xvalue_interval_to_indexes(dataset, min.value, max.value)

Arguments

dataset
list representing the dataset from a metabolomics experiment.
min.value
mininum x-value of the interval.
max.value
maximum x-value of the interval.

Value

Returns a numeric vector with the indexes of the x-values interval

Examples

Run this code
  ## Example of getting the indexes of an interval of x-values
  data(propolis)
  indexes.interval = xvalue_interval_to_indexes(propolis, 2.0, 5.5)

Run the code above in your browser using DataLab