Learn R Programming

specmine (version 4.0.0)

convert_keggpathway_2_reactiongraph: Convert KEGGPathway object to graph object

Description

Convert KEGGPathway object to graph object

Usage

convert_keggpathway_2_reactiongraph(pathObj)

Value

A graph object representing the reactions in the input

KEGGPathway object. The returned object is suitable for graph-based inspection or for use in downstream visualization functions.

Arguments

pathObj

TODO.

Examples

Run this code
if (FALSE) {
path <- get_MetabolitePath("hsa00010")
graph <- convert_keggpathway_2_reactiongraph(path)
class(graph)
}

Run the code above in your browser using DataLab