powered by
Convert KEGGPathway object to graph object
convert_keggpathway_2_reactiongraph(pathObj)
A graph object representing the reactions in the input
KEGGPathway object. The returned object is suitable for graph-based inspection or for use in downstream visualization functions.
KEGGPathway
TODO.
if (FALSE) { path <- get_MetabolitePath("hsa00010") graph <- convert_keggpathway_2_reactiongraph(path) class(graph) }
Run the code above in your browser using DataLab