powered by
Creates the pathway, with reactions included in the nodes
create_pathway_with_reactions( path, path.name, identified_cpds, nodeNames = "kegg", nodeTooltip = FALSE, map.zoom = FALSE, map.layout = "preset", map.width = NULL, map.height = NULL )
A cyjShiny widget representing the pathway with reactions included in the nodes. The widget contains the pathway graph ready for interactive visualization, with identified compounds highlighted when they are present in the pathway.
cyjShiny
TODO.
if (FALSE) { path <- get_MetabolitePath("hsa00010") create_pathway_with_reactions( path = path, path.name = "hsa00010", identified_cpds = c("cpd:C00031", "cpd:C00022") ) }
Run the code above in your browser using DataLab