View source: R/PATHWAY_ANALYSIS.R
| get_OrganismsCodes | R Documentation |
Get code, t number, full name and phylogeny of all organisms in KEGG:
get_OrganismsCodes()
A data.frame with the KEGG T number, organism code, species
names, and phylogeny for all organisms available in KEGG. Each row
represents one organism and the columns are Tnumber,
organismCode, speciesNames, and phylogeny.
## Not run:
head(get_OrganismsCodes())
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.