get_OrganismsCodes: Get code, t number, full name and phylogeny of all organisms in KEGG:
Description
Get code, t number, full name and phylogeny of all organisms in KEGG:
Usage
get_OrganismsCodes()
Arguments
Value
A data.frame with the KEGG T number, organism code, species
names, and phylogeny for all organisms available in KEGG. Each row
represents one organism and the columns are Tnumber,