View source: R/PATHWAY_ANALYSIS.R
| get_cpd_names | R Documentation |
Returns compound names associated with KEGG compound identifiers.
get_cpd_names(kegg_codes)
kegg_codes |
Character vector of KEGG compound identifiers. |
A named character vector in which the values are KEGG compound
identifiers and the names are the corresponding compound names. Each element
of the returned vector represents one KEGG compound code matched to its
primary compound name.
## Not run:
get_cpd_names(c("C00031", "C00022"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.