Learn R Programming

specmine (version 4.0.0)

get_cpd_names: Get compound names from KEGG codes

Description

Returns compound names associated with KEGG compound identifiers.

Usage

get_cpd_names(kegg_codes)

Value

A named character vector in which the values are KEGG compound identifiers and the names are the corresponding compound names. Each element of the returned vector represents one KEGG compound code matched to its primary compound name.

Arguments

kegg_codes

Character vector of KEGG compound identifiers.

Examples

Run this code
if (FALSE) {
get_cpd_names(c("C00031", "C00022"))
}

Run the code above in your browser using DataLab