Returns compound names associated with KEGG compound identifiers.
Usage
get_cpd_names(kegg_codes)
Value
A named character vector in which the values are KEGG compound
identifiers and the names are the corresponding compound names. Each element
of the returned vector represents one KEGG compound code matched to its
primary compound name.