View source: R/get_metabolights_study.R
| get_files_list_per_assay | R Documentation |
Auto-exported function: get_files_list_per_assay
get_files_list_per_assay(studyID)
studyID |
Character string with the MetaboLights study identifier. |
A named list of data.frame objects, one per assay, each containing
the sample names and corresponding file names for the specified study. Each data frame has
two columns: Samples, with sample identifiers, and Files, with the associated
raw or spectral data file names available in MetaboLights.
## Not run:
assays <- get_files_list_per_assay("MTBLS1")
names(assays)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.