Learn R Programming

specmine (version 4.0.0)

get_files_list_per_assay: Auto-exported function: get_files_list_per_assay

Description

Auto-exported function: get_files_list_per_assay

Usage

get_files_list_per_assay(studyID)

Value

A named list of data.frame objects, one per assay, each containing the sample names and corresponding file names for the specified study. Each data frame has two columns: Samples, with sample identifiers, and Files, with the associated raw or spectral data file names available in MetaboLights.

Arguments

studyID

Character string with the MetaboLights study identifier.

Examples

Run this code
if (FALSE) {
assays <- get_files_list_per_assay("MTBLS1")
names(assays)
}

Run the code above in your browser using DataLab