View source: R/PATHWAY_ANALYSIS.R
| get_metabPaths_org | R Documentation |
Get vector with paths numbers that occur in the given organism, named with the full path name:
get_metabPaths_org(org_code)
org_code |
TODO. |
A named character vector with the pathway identifiers
available for the specified organism, where each value is an organism-specific
pathway code and each name is the corresponding KEGG pathway name.
## Not run:
head(get_metabPaths_org("hsa"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.