Learn R Programming

specmine (version 4.0.0)

get_metabPaths_org: Get vector with paths numbers that occur in the given organism, named with the full path name:

Description

Get vector with paths numbers that occur in the given organism, named with the full path name:

Usage

get_metabPaths_org(org_code)

Value

A named character vector with the pathway identifiers available for the specified organism, where each value is an organism-specific pathway code and each name is the corresponding KEGG pathway name.

Arguments

org_code

TODO.

Examples

Run this code
if (FALSE) {
head(get_metabPaths_org("hsa"))
}

Run the code above in your browser using DataLab