powered by
Downloads files and metadata for every assay in a public MetaboLights study.
get_metabolights_study(studyID, directory, verbose = TRUE)
Invisibly returns a list with one entry per assay containing downloaded files, metadata, and sample-file mappings.
list
Character string with the MetaboLights study identifier.
Output directory where study files and metadata will be written.
Logical indicating whether progress messages should be shown.
if (FALSE) { tmpdir <- tempdir() get_metabolights_study("MTBLS1", directory = tmpdir, verbose = FALSE) }
Run the code above in your browser using DataLab