View source: R/get_metabolights_study.R
| get_metabolights_study_files_assay | R Documentation |
Downloads the data files associated with one assay of a MetaboLights study.
get_metabolights_study_files_assay(studyID, assay, directory, verbose = TRUE)
studyID |
Character string with the MetaboLights study identifier. |
assay |
Numeric or character index selecting the assay in the study. |
directory |
Output directory where assay files will be downloaded. |
verbose |
Logical indicating whether progress messages should be shown. |
Invisibly returns a character vector with downloaded file paths.
## Not run:
tmpdir <- tempdir()
get_metabolights_study_files_assay("MTBLS1", assay = 1, directory = tmpdir, verbose = FALSE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.