Learn R Programming

specmine (version 4.0.0)

get_metabolights_study_files_assay: Download files for one MetaboLights assay

Description

Downloads the data files associated with one assay of a MetaboLights study.

Usage

get_metabolights_study_files_assay(studyID, assay, directory, verbose = TRUE)

Value

Invisibly returns a character vector with downloaded file paths.

Arguments

studyID

Character string with the MetaboLights study identifier.

assay

Numeric or character index selecting the assay in the study.

directory

Output directory where assay files will be downloaded.

verbose

Logical indicating whether progress messages should be shown.

Examples

Run this code
if (FALSE) {
tmpdir <- tempdir()
get_metabolights_study_files_assay("MTBLS1", assay = 1, directory = tmpdir, verbose = FALSE)
}

Run the code above in your browser using DataLab