powered by
Downloads the data files associated with one assay of a MetaboLights study.
get_metabolights_study_files_assay(studyID, assay, directory, verbose = TRUE)
Invisibly returns a character vector with downloaded file paths.
character
Character string with the MetaboLights study identifier.
Numeric or character index selecting the assay in the study.
Output directory where assay files will be downloaded.
Logical indicating whether progress messages should be shown.
if (FALSE) { tmpdir <- tempdir() get_metabolights_study_files_assay("MTBLS1", assay = 1, directory = tmpdir, verbose = FALSE) }
Run the code above in your browser using DataLab