View source: R/get_metabolights_study.R
| get_metabolights_study_metadata_assay | R Documentation |
Returns the metadata associated with the samples in one assay of a MetaboLights study and can optionally save it as a CSV file.
get_metabolights_study_metadata_assay(studyID, assay, directory = NULL)
studyID |
Character string with the MetaboLights study identifier. |
assay |
Numeric or character index selecting the assay in the study. |
directory |
Optional output directory where the metadata CSV will be written. |
Invisibly returns a data.frame with sample metadata for the selected assay.
## Not run:
md <- get_metabolights_study_metadata_assay("MTBLS1", assay = 1)
head(md)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.