Learn R Programming

specmine (version 4.0.0)

get_metabolights_study_metadata_assay: Get metadata for one MetaboLights assay

Description

Returns the metadata associated with the samples in one assay of a MetaboLights study and can optionally save it as a CSV file.

Usage

get_metabolights_study_metadata_assay(studyID, assay, directory = NULL)

Value

Invisibly returns a data.frame with sample metadata for the selected assay.

Arguments

studyID

Character string with the MetaboLights study identifier.

assay

Numeric or character index selecting the assay in the study.

directory

Optional output directory where the metadata CSV will be written.

Examples

Run this code
if (FALSE) {
md <- get_metabolights_study_metadata_assay("MTBLS1", assay = 1)
head(md)
}

Run the code above in your browser using DataLab