powered by
Returns the metadata associated with the samples in one assay of a MetaboLights study and can optionally save it as a CSV file.
get_metabolights_study_metadata_assay(studyID, assay, directory = NULL)
Invisibly returns a data.frame with sample metadata for the selected assay.
data.frame
Character string with the MetaboLights study identifier.
Numeric or character index selecting the assay in the study.
Optional output directory where the metadata CSV will be written.
if (FALSE) { md <- get_metabolights_study_metadata_assay("MTBLS1", assay = 1) head(md) }
Run the code above in your browser using DataLab