View source: R/get_metabolights_study.R
| get_metabolights_study_samples_files | R Documentation |
Returns the sample-to-file mapping for one assay in a MetaboLights study and can optionally save it as a CSV file.
get_metabolights_study_samples_files(studyID, assay, directory = NULL)
studyID |
Character string with the MetaboLights study identifier. |
assay |
Numeric or character index selecting the assay in the study. |
directory |
Optional output directory where |
Invisibly returns a two-column object with samples and corresponding files.
## Not run:
get_metabolights_study_samples_files("MTBLS1", assay = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.