Learn R Programming

specmine (version 4.0.0)

get_metabolights_study_samples_files: Get sample-file mapping for one MetaboLights assay

Description

Returns the sample-to-file mapping for one assay in a MetaboLights study and can optionally save it as a CSV file.

Usage

get_metabolights_study_samples_files(studyID, assay, directory = NULL)

Value

Invisibly returns a two-column object with samples and corresponding files.

Arguments

studyID

Character string with the MetaboLights study identifier.

assay

Numeric or character index selecting the assay in the study.

directory

Optional output directory where samples_files.csv will be written.

Examples

Run this code
if (FALSE) {
get_metabolights_study_samples_files("MTBLS1", assay = 1)
}

Run the code above in your browser using DataLab