powered by
Returns the sample-to-file mapping for one assay in a MetaboLights study and can optionally save it as a CSV file.
get_metabolights_study_samples_files(studyID, assay, directory = NULL)
Invisibly returns a two-column object with samples and corresponding files.
Character string with the MetaboLights study identifier.
Numeric or character index selecting the assay in the study.
Optional output directory where samples_files.csv will be written.
samples_files.csv
if (FALSE) { get_metabolights_study_samples_files("MTBLS1", assay = 1) }
Run the code above in your browser using DataLab