Learn R Programming

specmine (version 4.0.0)

get_paths_with_cpds_org: Get only the paths of the organism that contain given compounds:

Description

Get only the paths of the organism that contain given compounds:

Usage

get_paths_with_cpds_org(organism_code, compounds, full.result = TRUE)

Value

A data.frame with the pathways containing the input compounds. Each row represents one matched pathway. When full.result = TRUE, the returned data frame includes the columns pathways, ratio,

compounds, and compounds_names; otherwise it contains only

pathways and ratio. Row names correspond to pathway names.

Arguments

organism_code

TODO.

compounds

TODO.

full.result

TODO.

Examples

Run this code
if (FALSE) {
cpds <- c(glucose = "cpd:C00031", pyruvate = "cpd:C00022")
head(get_paths_with_cpds_org("hsa", cpds, full.result = FALSE))
}

Run the code above in your browser using DataLab