powered by
Auto-exported function: get_peak_values
get_peak_values(samples.df, peak.val)
A numeric vector with the intensity values for the peak specified by peak.val across all samples in samples.df.
peak.val
samples.df
A data frame of peak intensities with peaks in rows and samples in columns.
Peak value identifying the row to extract.
samples.df <- data.frame( s1 = c(10, 20), s2 = c(15, NA), row.names = c("1", "2") ) get_peak_values(samples.df, "1")
Run the code above in your browser using DataLab