Replace missing values in each variable by the mean of the observed values
for that variable.
Usage
impute_nas_mean(dataset)
Value
A dataset object with the same structure as the input, where missing
values in `dataset$data` have been replaced by the mean of the corresponding
variable calculated with `na.rm = TRUE`.