impute_nas_median: Impute missing values with median
Description
Replace missing values in each variable by the median of the observed values
for that variable.
Usage
impute_nas_median(dataset)
Value
A dataset object with the same structure as the input, where missing
values in `dataset$data` have been replaced by the median of the corresponding
variable calculated with `na.rm = TRUE`.