Learn R Programming

specmine (version 4.0.0)

pathway_analysis: Creates the pathway wanted. If any of the given compounds is present in the pathway, it is coloured differently.

Description

Creates the pathway wanted. If any of the given compounds is present in the pathway, it is coloured differently.

Usage

pathway_analysis(
  compounds,
  pathway,
  nodeNames = "kegg",
  nodeTooltip = FALSE,
  map.zoom = FALSE,
  map.layout = "preset",
  map.width = NULL,
  map.height = NULL,
  verbose = TRUE
)

Value

A cyjShiny widget representing the selected pathway with the input compounds highlighted when present. The returned widget can be printed or embedded in an interactive R session to inspect the pathway graph.

Arguments

compounds

TODO.

pathway

TODO.

nodeNames

TODO.

nodeTooltip

TODO.

map.zoom

TODO.

map.layout

TODO.

map.width

TODO.

map.height

TODO.

verbose

Logical indicating whether progress messages should be shown.

Examples

Run this code
if (FALSE) {
pathway_analysis(
  compounds = c(glucose = "cpd:C00031", pyruvate = "cpd:C00022"),
  pathway = "hsa00010",
  verbose = FALSE
)
}

Run the code above in your browser using DataLab