| pca_screeplot | R Documentation |
Draws a scree plot with individual and cumulative explained variance.
pca_screeplot(
pca.result,
num.pcs = NULL,
cex.leg = 0.8,
leg.pos = "right",
lab.text = c("individual percent", "cumulative percent"),
fill.col = c("blue", "red"),
ylab = "Percentage",
xlab = "Principal components",
...
)
pca.result |
PCA result object. |
num.pcs |
Number of principal components to display. |
cex.leg |
Legend text size. |
leg.pos |
Legend position. |
lab.text |
Legend labels. |
fill.col |
Line colours. |
ylab |
Y-axis label. |
xlab |
X-axis label. |
... |
Additional graphical parameters. |
No return value, called for its side effect of plotting.
datamat <- matrix(
rnorm(20),
nrow = 4,
dimnames = list(paste0("x", 1:4), paste0("s", 1:5))
)
metadata <- data.frame(class = factor(c("A", "A", "B", "B", "A")))
dataset <- list(data = datamat, metadata = metadata)
pca_res <- pca_analysis_dataset(dataset)
pca_screeplot(pca_res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.