| read_spc_nosubhdr | R Documentation |
Import for Thermo Galactic's spc file format These functions allow to import .spc files. A detailed description of the .spc file format is available at
read_spc_nosubhdr(
filename,
keys.hdr2data = c("fexper", "fres", "fsource"),
keys.hdr2log = c("fdate", "fpeakpt"),
keys.log2data = FALSE,
keys.log2log = TRUE,
log.txt = TRUE,
log.bin = FALSE,
log.disk = FALSE,
hdr = list(),
nosubhdr = TRUE,
no.object = FALSE
)
filename |
The complete file name of the .spc file. |
keys.hdr2data, keys.hdr2log, keys.log2data, keys.log2log |
character
vectors with the names of parameters in the .spc file's log block
(log2xxx) or header (hdr2xxx) that should go into the extra data
(yyy2data) or into the |
log.txt |
Should the text part of the .spc file's log block be read? |
log.bin, log.disk |
Should the normal and on-disk binary parts of the .spc file's log block be read? |
hdr |
A list with fileheader fields that overwrite the settings of actual file's header. |
nosubhdr |
Boolean value to decide if the header should be read or not. |
no.object |
If |
A list with imported spectra information.
C. Beleites
Reference information for the SPC file format.
filename <- system.file("extdata", "toy.spc", package = "specmine")
if (nzchar(filename)) {
read_spc_nosubhdr(filename)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.