read_spc_nosubhdr: Import for Thermo Galactic's spc file format
These functions allow to import .spc files.
A detailed description of the .spc file format is available at
Description
Import for Thermo Galactic's spc file format
These functions allow to import .spc files.
A detailed description of the .spc file format is available at
character
vectors with the names of parameters in the .spc file's log block
(log2xxx) or header (hdr2xxx) that should go into the extra data
(yyy2data) or into the long.description field of the returned
object's log (yyy2log).
log.txt
Should the text part of the .spc file's log block be read?
log.bin, log.disk
Should the normal and on-disk binary parts of the
.spc file's log block be read?
hdr
A list with fileheader fields that overwrite the settings of
actual file's header.
nosubhdr
Boolean value to decide if the header should be read or not.
no.object
If TRUE, a list with wavelengths, spectra, labels,
log and data are returned instead of a hyperSpec object.