powered by
Smoothing and derivative of the data using Savitzky-Golay.
savitzky_golay(dataset, p.order, window, deriv = 0)
list representing the dataset from a metabolomics experiment.
integer value representing the polynomial order.
odd number indicating the window size.
integer value indicating the differentiation order.
Returns the dataset with the spectra smoothed using Savitzky-Golay.
# NOT RUN { ## Example of smoothing the spectra from dataset with Savitzky-Golay data(cassavaPPD) dataset.smoothed = savitzky_golay(cassavaPPD, p.order = 3, window = 11, deriv = 0) # }
Run the code above in your browser using DataLab