powered by
Converts transmittance values to absorbance values.
transmittance_to_absorbance(dataset, percent = T)
list representing the dataset from a metabolomics experiment.
boolean value to indicate if the absorbance values are in a percentage or not.
Returns the dataset with the data points converted to absorbance values.
# NOT RUN { ## Example of converting transmittance values to absorbance values data(cassavaPPD) dataset = transmittance_to_absorbance(cassavaPPD, percent = TRUE) # }
Run the code above in your browser using DataLab