Learn R Programming

specmine (version 1.0)

transmittance_to_absorbance: Convert transmittance to absorbance

Description

Converts transmittance values to absorbance values.

Usage

transmittance_to_absorbance(dataset, percent = T)

Arguments

dataset
list representing the dataset from a metabolomics experiment.
percent
boolean value to indicate if the absorbance values are in a percentage or not.

Value

Returns the dataset with the data points converted to absorbance values.

Examples

Run this code
  ## Example of converting transmittance values to absorbance values
  data(cassavaPPD)
  dataset = transmittance_to_absorbance(cassavaPPD, percent = TRUE)

Run the code above in your browser using DataLab